@@ -331,32 +331,36 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
 @task
-def build2():
+def build2(javaEnv,dirs):
 
 
     # ensure maven installs all build tools
     local("pwd")
     local('mvn clean install -DskipTests')
+
+
     local('mkdir -p deploy/api/config')
     local('mkdir -p deploy/api/lib')
-    local('mkdir -p deploy/worker/config')
-    local('mkdir -p deploy/worker/lib')
  
-    local('cp config/keyset-prod.json deploy/api/config/keyset.json')
+    local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
     local('cp config/logback.xml deploy/api/config/')
-    local('cp config/application-prod.yml deploy/api/config/')
+    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
 
     local('cp -r api/target/lib/ deploy/api/')
 
     local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
-    local('cp config/keyset-prod.json deploy/worker/config/keyset.json')
-    local('cp config/logback.xml deploy/worker/config/')
-    local('cp config/application-prod-worker.yml deploy/worker/config/')
 
-    local('cp -r worker/target/lib/ deploy/worker/')
+#   local('mkdir -p deploy/worker/config')
+#    local('mkdir -p deploy/worker/lib')
 
-    local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
+#    local('cp config/keyset-prod.json deploy/worker/config/keyset.json')
+#    local('cp config/logback.xml deploy/worker/config/')
+#    local('cp config/application-prod-worker.yml deploy/worker/config/')
+
+#    local('cp -r worker/target/lib/ deploy/worker/')
+
+#    local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
 
 
 
